# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admobilize/billing/v1alpha1/billing.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='admobilize/billing/v1alpha1/billing.proto',
  package='admobilize.billing.v1alpha1',
  syntax='proto3',
  serialized_options=_b('\n\037com.admobilize.billing.v1alpha1B\014BillingProtoP\001\242\002\005ADMBL\252\002\033AdMobilize.Billing.V1Alpha1'),
  serialized_pb=_b('\n)admobilize/billing/v1alpha1/billing.proto\x12\x1b\x61\x64mobilize.billing.v1alpha1\"B\n\x0e\x42illingAccount\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04open\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\"T\n\x12ProjectBillingInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x1c\n\x14\x62illing_account_name\x18\x03 \x01(\tBW\n\x1f\x63om.admobilize.billing.v1alpha1B\x0c\x42illingProtoP\x01\xa2\x02\x05\x41\x44MBL\xaa\x02\x1b\x41\x64Mobilize.Billing.V1Alpha1b\x06proto3')
)




_BILLINGACCOUNT = _descriptor.Descriptor(
  name='BillingAccount',
  full_name='admobilize.billing.v1alpha1.BillingAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='admobilize.billing.v1alpha1.BillingAccount.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open', full_name='admobilize.billing.v1alpha1.BillingAccount.open', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='admobilize.billing.v1alpha1.BillingAccount.display_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=140,
)


_PROJECTBILLINGINFO = _descriptor.Descriptor(
  name='ProjectBillingInfo',
  full_name='admobilize.billing.v1alpha1.ProjectBillingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='admobilize.billing.v1alpha1.ProjectBillingInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='admobilize.billing.v1alpha1.ProjectBillingInfo.project_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billing_account_name', full_name='admobilize.billing.v1alpha1.ProjectBillingInfo.billing_account_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=226,
)

DESCRIPTOR.message_types_by_name['BillingAccount'] = _BILLINGACCOUNT
DESCRIPTOR.message_types_by_name['ProjectBillingInfo'] = _PROJECTBILLINGINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BillingAccount = _reflection.GeneratedProtocolMessageType('BillingAccount', (_message.Message,), dict(
  DESCRIPTOR = _BILLINGACCOUNT,
  __module__ = 'admobilize.billing.v1alpha1.billing_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.billing.v1alpha1.BillingAccount)
  ))
_sym_db.RegisterMessage(BillingAccount)

ProjectBillingInfo = _reflection.GeneratedProtocolMessageType('ProjectBillingInfo', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTBILLINGINFO,
  __module__ = 'admobilize.billing.v1alpha1.billing_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.billing.v1alpha1.ProjectBillingInfo)
  ))
_sym_db.RegisterMessage(ProjectBillingInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
