# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admobilize/common/entity.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admobilize/common/entity.proto',
  package='admobilize.common',
  syntax='proto3',
  serialized_options=_b('\n\034com.admobilize.common.EntityB\013EntityProtoP\001\242\002\005ADMCE\252\002\021AdMobilize.Common'),
  serialized_pb=_b('\n\x1e\x61\x64mobilize/common/entity.proto\x12\x11\x61\x64mobilize.common\x1a\x1fgoogle/protobuf/timestamp.proto\"6\n\nArrayValue\x12(\n\x06values\x18\x01 \x03(\x0b\x32\x18.admobilize.common.Value\"\xad\x02\n\x05Value\x12\x17\n\rboolean_value\x18\x01 \x01(\x08H\x00\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x31\n\x0c\x65ntity_value\x18\x06 \x01(\x0b\x32\x19.admobilize.common.EntityH\x00\x12\x34\n\x0b\x61rray_value\x18\t \x01(\x0b\x32\x1d.admobilize.common.ArrayValueH\x00\x12\x35\n\x0ftimestamp_value\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x16\n\x0cstring_value\x18\x11 \x01(\tH\x00\x12\x14\n\nblob_value\x18\x12 \x01(\x0cH\x00\x42\x0c\n\nvalue_type\"\x94\x01\n\x06\x45ntity\x12=\n\nproperties\x18\x01 \x03(\x0b\x32).admobilize.common.Entity.PropertiesEntry\x1aK\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.admobilize.common.Value:\x02\x38\x01\x42I\n\x1c\x63om.admobilize.common.EntityB\x0b\x45ntityProtoP\x01\xa2\x02\x05\x41\x44MCE\xaa\x02\x11\x41\x64Mobilize.Commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_ARRAYVALUE = _descriptor.Descriptor(
  name='ArrayValue',
  full_name='admobilize.common.ArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='admobilize.common.ArrayValue.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=140,
)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='admobilize.common.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='boolean_value', full_name='admobilize.common.Value.boolean_value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_value', full_name='admobilize.common.Value.integer_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='admobilize.common.Value.double_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity_value', full_name='admobilize.common.Value.entity_value', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='array_value', full_name='admobilize.common.Value.array_value', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp_value', full_name='admobilize.common.Value.timestamp_value', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='admobilize.common.Value.string_value', index=6,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_value', full_name='admobilize.common.Value.blob_value', index=7,
      number=18, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value_type', full_name='admobilize.common.Value.value_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=143,
  serialized_end=444,
)


_ENTITY_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='admobilize.common.Entity.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='admobilize.common.Entity.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='admobilize.common.Entity.PropertiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=595,
)

_ENTITY = _descriptor.Descriptor(
  name='Entity',
  full_name='admobilize.common.Entity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='admobilize.common.Entity.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ENTITY_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=595,
)

_ARRAYVALUE.fields_by_name['values'].message_type = _VALUE
_VALUE.fields_by_name['entity_value'].message_type = _ENTITY
_VALUE.fields_by_name['array_value'].message_type = _ARRAYVALUE
_VALUE.fields_by_name['timestamp_value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['boolean_value'])
_VALUE.fields_by_name['boolean_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['integer_value'])
_VALUE.fields_by_name['integer_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['double_value'])
_VALUE.fields_by_name['double_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['entity_value'])
_VALUE.fields_by_name['entity_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['array_value'])
_VALUE.fields_by_name['array_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['timestamp_value'])
_VALUE.fields_by_name['timestamp_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['string_value'])
_VALUE.fields_by_name['string_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['blob_value'])
_VALUE.fields_by_name['blob_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_ENTITY_PROPERTIESENTRY.fields_by_name['value'].message_type = _VALUE
_ENTITY_PROPERTIESENTRY.containing_type = _ENTITY
_ENTITY.fields_by_name['properties'].message_type = _ENTITY_PROPERTIESENTRY
DESCRIPTOR.message_types_by_name['ArrayValue'] = _ARRAYVALUE
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['Entity'] = _ENTITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ArrayValue = _reflection.GeneratedProtocolMessageType('ArrayValue', (_message.Message,), dict(
  DESCRIPTOR = _ARRAYVALUE,
  __module__ = 'admobilize.common.entity_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.ArrayValue)
  ))
_sym_db.RegisterMessage(ArrayValue)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), dict(
  DESCRIPTOR = _VALUE,
  __module__ = 'admobilize.common.entity_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.Value)
  ))
_sym_db.RegisterMessage(Value)

Entity = _reflection.GeneratedProtocolMessageType('Entity', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _ENTITY_PROPERTIESENTRY,
    __module__ = 'admobilize.common.entity_pb2'
    # @@protoc_insertion_point(class_scope:admobilize.common.Entity.PropertiesEntry)
    ))
  ,
  DESCRIPTOR = _ENTITY,
  __module__ = 'admobilize.common.entity_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.Entity)
  ))
_sym_db.RegisterMessage(Entity)
_sym_db.RegisterMessage(Entity.PropertiesEntry)


DESCRIPTOR._options = None
_ENTITY_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
