# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admobilize/common/job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admobilize/common/job.proto',
  package='admobilize.common',
  syntax='proto3',
  serialized_options=_b('\n\025com.admobilize.commonB\010JobProtoP\001\242\002\003ACP\252\002 AdMobilize.common.WellKnownTypes'),
  serialized_pb=_b('\n\x1b\x61\x64mobilize/common/job.proto\x12\x11\x61\x64mobilize.common\x1a\x1fgoogle/protobuf/timestamp.proto\">\n\x08JobError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x03 \x01(\t\"\xa3\x01\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x13\n\x0bupdate_time\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12,\n\x06status\x18\x05 \x01(\x0e\x32\x1c.admobilize.common.JobStatus\x12*\n\x05\x65rror\x18\x06 \x01(\x0b\x32\x1b.admobilize.common.JobError*3\n\tJobStatus\x12\x0b\n\x07RUNNING\x10\x00\x12\x0b\n\x07\x45RRORED\x10\x01\x12\x0c\n\x08\x46INISHED\x10\x02\x42L\n\x15\x63om.admobilize.commonB\x08JobProtoP\x01\xa2\x02\x03\x41\x43P\xaa\x02 AdMobilize.common.WellKnownTypesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_JOBSTATUS = _descriptor.EnumDescriptor(
  name='JobStatus',
  full_name='admobilize.common.JobStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERRORED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=313,
  serialized_end=364,
)
_sym_db.RegisterEnumDescriptor(_JOBSTATUS)

JobStatus = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUS)
RUNNING = 0
ERRORED = 1
FINISHED = 2



_JOBERROR = _descriptor.Descriptor(
  name='JobError',
  full_name='admobilize.common.JobError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='admobilize.common.JobError.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='admobilize.common.JobError.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='admobilize.common.JobError.details', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=145,
)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='admobilize.common.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admobilize.common.Job.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='admobilize.common.Job.create_time', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='admobilize.common.Job.update_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='admobilize.common.Job.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='admobilize.common.Job.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='admobilize.common.Job.error', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=311,
)

_JOB.fields_by_name['status'].enum_type = _JOBSTATUS
_JOB.fields_by_name['error'].message_type = _JOBERROR
DESCRIPTOR.message_types_by_name['JobError'] = _JOBERROR
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.enum_types_by_name['JobStatus'] = _JOBSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JobError = _reflection.GeneratedProtocolMessageType('JobError', (_message.Message,), dict(
  DESCRIPTOR = _JOBERROR,
  __module__ = 'admobilize.common.job_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.JobError)
  ))
_sym_db.RegisterMessage(JobError)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), dict(
  DESCRIPTOR = _JOB,
  __module__ = 'admobilize.common.job_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.Job)
  ))
_sym_db.RegisterMessage(Job)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
