# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from admobilize.proto.ayuda.v1alpha1 import ayuda_service_pb2 as admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2
from admobilize.proto.common import job_pb2 as admobilize_dot_common_dot_job__pb2


class AyudaServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateSnapshot = channel.unary_unary(
        '/admobilize.ayuda.v1alpha1.AyudaService/CreateSnapshot',
        request_serializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.SnapshotRequest.SerializeToString,
        response_deserializer=admobilize_dot_common_dot_job__pb2.Job.FromString,
        )
    self.CreateOptimizedSnapshot = channel.unary_unary(
        '/admobilize.ayuda.v1alpha1.AyudaService/CreateOptimizedSnapshot',
        request_serializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.OptimizedSnapshotRequest.SerializeToString,
        response_deserializer=admobilize_dot_common_dot_job__pb2.Job.FromString,
        )
    self.CreateReport = channel.unary_unary(
        '/admobilize.ayuda.v1alpha1.AyudaService/CreateReport',
        request_serializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.ReportRequest.SerializeToString,
        response_deserializer=admobilize_dot_common_dot_job__pb2.Job.FromString,
        )


class AyudaServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateSnapshot(self, request, context):
    """Run the Ayuda snapshotting pipeline
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateOptimizedSnapshot(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateReport(self, request, context):
    """Run the Ayuda reporting pipeline
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AyudaServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateSnapshot': grpc.unary_unary_rpc_method_handler(
          servicer.CreateSnapshot,
          request_deserializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.SnapshotRequest.FromString,
          response_serializer=admobilize_dot_common_dot_job__pb2.Job.SerializeToString,
      ),
      'CreateOptimizedSnapshot': grpc.unary_unary_rpc_method_handler(
          servicer.CreateOptimizedSnapshot,
          request_deserializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.OptimizedSnapshotRequest.FromString,
          response_serializer=admobilize_dot_common_dot_job__pb2.Job.SerializeToString,
      ),
      'CreateReport': grpc.unary_unary_rpc_method_handler(
          servicer.CreateReport,
          request_deserializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.ReportRequest.FromString,
          response_serializer=admobilize_dot_common_dot_job__pb2.Job.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'admobilize.ayuda.v1alpha1.AyudaService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
